@@ -69,7 +69,9 @@ class CloneMixinTestCase(TestCase):
         self.assertEqual(instance.name, name)
         self.assertEqual(clone.created_by, instance.created_by)
 
-        self.assertNotEqual(instance.created_at, clone.created_at)
+        self.assertNotEqual(
+            instance.created_at.isoformat(), clone.created_at.isoformat()
+        )
 
     def test_cloning_without_explicit_clone_m2m_fields(self):
         author_1 = Author.objects.create(
